@@ -28,6 +28,7 @@ from .const import (
     CONF_NONE,
     CONF_OPEN_PRESET,
     CONF_PRESET,
+    CONF_QUERY_CHANNEL,
     CONF_ROOM,
     CONF_ROOM_OFF,
     CONF_ROOM_ON,
@@ -37,11 +38,15 @@ from .const import (
     CONF_TIME_COVER,
     CONF_TRGT_LEVEL,
     DEFAULT_CHANNEL_TYPE,
+    DEFAULT_COVER_CLASS,
     EVENT_CHANNEL,
     EVENT_CONNECTED,
     EVENT_DISCONNECTED,
+    EVENT_PACKET,
     EVENT_PRESET,
     LOGGER,
+    NOTIFICATION_PACKET,
+    NOTIFICATION_PRESET,
 )
 from .cover import DynaliteTimeCoverDevice, DynaliteTimeCoverWithTiltDevice
 from .dynalite import Dynalite
@@ -55,6 +60,29 @@ from .switch import (
 )
 
 
+class DynaliteNotification:
+    """A notification from the network that is sent to the application."""
+
+    def __init__(self, notification: str, data: Dict[str, Any]):
+        """Create a notification."""
+        self.notification = notification
+        self.data = data
+
+    def __repr__(self):
+        """Print a notification for logs."""
+        return (
+            "DynaliteNotification(notification="
+            + self.notification
+            + ", data="
+            + str(self.data)
+            + ")"
+        )
+
+    def __eq__(self, other):
+        """Compare two notification, mostly for debug."""
+        return self.notification == other.notification and self.data == other.data
+
+
 class DynaliteDevices:
     """Manages a single Dynalite bridge."""
 
@@ -62,6 +90,7 @@ class DynaliteDevices:
         self,
         new_device_func: Callable[[List[DynaliteBaseDevice]], None],
         update_device_func: Callable[[Optional[DynaliteBaseDevice]], None],
+        notification_func: Callable[[DynaliteNotification], None],
     ) -> None:
         """Initialize the system."""
         self._host = ""
@@ -69,11 +98,13 @@ class DynaliteDevices:
         self.name = None  # public
         self._poll_timer = 0.0
         self._default_fade = 0.0
+        self._default_query_channel = 0
         self._active = ""
         self._auto_discover = None
         self._loop: Optional[asyncio.AbstractEventLoop] = None
         self._new_device_func = new_device_func
         self._update_device_func = update_device_func
+        self._notification_func = notification_func
         self._configured = False
         self.connected = False  # public
         self._added_presets: Dict[int, Any] = {}
@@ -86,6 +117,7 @@ class DynaliteDevices:
         self._area: Dict[int, Any] = {}
         self._dynalite = Dynalite(broadcast_func=self.handle_event)
         self._resetting = False
+        self._default_presets: Dict[int, Any] = {}
 
     async def async_setup(self) -> bool:
         """Set up a Dynalite bridge based on host parameter in the config."""
@@ -109,16 +141,22 @@ class DynaliteDevices:
         self._active = configurator.active
         self._poll_timer = configurator.poll_timer
         self._default_fade = configurator.default_fade
+        self._default_query_channel = configurator.default_query_channel
+        # keep the old values in case of a reconfigure, for auto discovery
+        old_area = self._area
         self._area = configurator.area
+        for area in old_area:
+            if area not in self._area:
+                self._area[area] = old_area[area]
         self._default_presets = configurator.default_presets
         # now register the channels and presets and ask for initial status if needed
         for area in self._area:
             if self._active in [ACTIVE_INIT, ACTIVE_ON]:
-                self._dynalite.request_area_preset(area)
+                self.request_area_preset(area, self._area[area][CONF_QUERY_CHANNEL])
             for channel in self._area[area][CONF_CHANNEL]:
                 self.create_channel_if_new(area, channel)
                 if self._active in [ACTIVE_INIT, ACTIVE_ON]:
-                    self._dynalite.request_channel_level(area, channel)
+                    self.request_channel_level(area, channel)
             for preset in self._area[area][CONF_PRESET]:
                 self.create_preset_if_new(area, preset)
         # register the rooms (switches on presets 1/4)
@@ -138,7 +176,7 @@ class DynaliteDevices:
             if area_config.get(CONF_TEMPLATE, "") == CONF_ROOM:
                 if area in self._added_room_switches:
                     continue
-                new_device = DynaliteDualPresetSwitchDevice(area, self)
+                new_device = DynaliteDualPresetSwitchDevice(area, self, False)
                 self._added_room_switches[area] = new_device
                 new_device.set_device(
                     1, self._added_presets[area][area_config[CONF_ROOM_ON]]
@@ -146,7 +184,7 @@ class DynaliteDevices:
                 new_device.set_device(
                     2, self._added_presets[area][area_config[CONF_ROOM_OFF]]
                 )
-                self.register_new_device(new_device, False)
+                self.register_new_device(new_device)
 
     def register_time_covers(self) -> None:
         """Register the time covers from three presets and a channel each."""
@@ -155,10 +193,12 @@ class DynaliteDevices:
                 if area in self._added_time_covers:
                     continue
                 if area_config[CONF_TILT_TIME] == 0:
-                    new_device = DynaliteTimeCoverDevice(area, self, self._poll_timer)
+                    new_device = DynaliteTimeCoverDevice(
+                        area, self, self._poll_timer, False
+                    )
                 else:
                     new_device = DynaliteTimeCoverWithTiltDevice(
-                        area, self, self._poll_timer
+                        area, self, self._poll_timer, False
                     )
                 self._added_time_covers[area] = new_device
                 new_device.set_device(
@@ -175,14 +215,14 @@ class DynaliteDevices:
                         area_config[CONF_CHANNEL_COVER]
                     ]
                 else:
-                    channel_device = DynaliteBaseDevice(area, self)
+                    channel_device = DynaliteBaseDevice(area, self, True)
                 new_device.set_device(4, channel_device)
-                self.register_new_device(new_device, False)
+                self.register_new_device(new_device)
 
-    def register_new_device(self, device: DynaliteBaseDevice, hidden: bool) -> None:
+    def register_new_device(self, device: DynaliteBaseDevice) -> None:
         """Register a new device and group all the ones prior to CONFIGURED event together."""
         # after initial configuration, every new device gets sent on its own. The initial ones are bunched together
-        if not hidden:
+        if not device.hidden:
             if self._configured:
                 self._new_device_func([device])
             else:  # send all the devices together when configured
@@ -199,8 +239,14 @@ class DynaliteDevices:
 
     def update_device(self, device: Optional[DynaliteBaseDevice] = None) -> None:
         """Update one or more devices."""
+        if device and device.hidden:
+            return
         self._update_device_func(device)
 
+    def send_notification(self, notification: DynaliteNotification) -> None:
+        """Update one or more devices."""
+        self._notification_func(notification)
+
     def handle_event(self, event: DynetEvent) -> None:
         """Handle all events."""
         LOGGER.debug("handle_event - type=%s event=%s", event.event_type, event.data)
@@ -214,11 +260,29 @@ class DynaliteDevices:
             self.update_device()
         elif event.event_type == EVENT_PRESET:
             LOGGER.debug("Received PRESET message")
+            assert event.data
             self.handle_preset_selection(event)
-        else:
-            assert event.event_type == EVENT_CHANNEL
+            self.send_notification(
+                DynaliteNotification(
+                    NOTIFICATION_PRESET,
+                    {
+                        CONF_AREA: event.data[CONF_AREA],
+                        CONF_PRESET: event.data[CONF_PRESET],
+                    },
+                )
+            )
+        elif event.event_type == EVENT_CHANNEL:
             LOGGER.debug("Received CHANNEL message")
             self.handle_channel_change(event)
+        else:
+            assert event.event_type == EVENT_PACKET
+            assert event.data
+            LOGGER.debug("Received PACKET message")
+            self.send_notification(
+                DynaliteNotification(
+                    NOTIFICATION_PACKET, {NOTIFICATION_PACKET: event.data[EVENT_PACKET]}
+                )
+            )
 
     def ensure_area(self, area: int) -> None:
         """Configure a default area if it is not yet in config."""
@@ -226,7 +290,7 @@ class DynaliteDevices:
             LOGGER.debug("adding area %s that is not in config", area)
             # consider adding default presets to new areas (XXX)
             self._area[area] = DynaliteConfig.configure_area(
-                area, {}, self._default_fade, {}, {}
+                area, {}, self._default_fade, self._default_query_channel, {}, {}
             )
 
     def create_preset_if_new(self, area: int, preset: int) -> None:
@@ -248,9 +312,9 @@ class DynaliteDevices:
             if area_config.get(CONF_TEMPLATE, False):
                 area_config[CONF_PRESET][preset][CONF_HIDDEN_ENTITY] = True
         hidden = area_config[CONF_PRESET][preset].get(CONF_HIDDEN_ENTITY, False)
-        new_device = DynalitePresetSwitchDevice(area, preset, self,)
+        new_device = DynalitePresetSwitchDevice(area, preset, self, hidden)
         new_device.set_level(0)
-        self.register_new_device(new_device, hidden)
+        self.register_new_device(new_device)
         if area not in self._added_presets:
             self._added_presets[area] = {}
         self._added_presets[area][preset] = new_device
@@ -276,7 +340,7 @@ class DynaliteDevices:
         # If active is set to full, query all channels in the area
         if self._active == ACTIVE_ON:
             for channel in self._area[area].get(CONF_CHANNEL, {}):
-                self._dynalite.request_channel_level(area, channel)
+                self.request_channel_level(area, channel)
 
     def create_channel_if_new(self, area: int, channel: int) -> None:
         """Register a new channel."""
@@ -301,12 +365,12 @@ class DynaliteDevices:
         hidden = channel_config.get(CONF_HIDDEN_ENTITY, False)
         if channel_type == "light":
             new_device: DynaliteBaseDevice = DynaliteChannelLightDevice(
-                area, channel, self,
+                area, channel, self, hidden
             )
-            self.register_new_device(new_device, hidden)
+            self.register_new_device(new_device)
         elif channel_type == "switch":
-            new_device = DynaliteChannelSwitchDevice(area, channel, self,)
-            self.register_new_device(new_device, hidden)
+            new_device = DynaliteChannelSwitchDevice(area, channel, self, hidden)
+            self.register_new_device(new_device)
         else:
             LOGGER.info("unknown chnanel type %s - ignoring", channel_type)
             return
@@ -392,6 +456,19 @@ class DynaliteDevices:
         """Select a preset in an area."""
         self._dynalite.select_preset(area, preset, fade)
 
+    def request_area_preset(self, area: int, query_channel: Optional[int]) -> None:
+        """Send a request to an area to report the preset."""
+        if query_channel is None:
+            if area in self._area:
+                query_channel = self._area[area][CONF_QUERY_CHANNEL]
+            else:
+                query_channel = self._default_query_channel
+        self._dynalite.request_area_preset(area, query_channel)
+
+    def request_channel_level(self, area: int, channel: int) -> None:
+        """Send a request to an area to report the preset."""
+        self._dynalite.request_channel_level(area, channel)
+
     def get_area_name(self, area: int) -> str:
         """Return the name of an area."""
         return self._area[area][CONF_NAME]
@@ -405,7 +482,10 @@ class DynaliteDevices:
 
     def get_channel_fade(self, area: int, channel: int) -> float:
         """Return the fade of a channel."""
-        return self._area[area][CONF_CHANNEL][channel][CONF_FADE]
+        try:
+            return self._area[area][CONF_CHANNEL][channel][CONF_FADE]
+        except KeyError:
+            return self._default_fade
 
     def get_preset_name(self, area: int, preset: int) -> str:
         """Return the name of a preset."""
@@ -422,7 +502,10 @@ class DynaliteDevices:
 
     def get_preset_fade(self, area: int, preset: int) -> float:
         """Return the fade of a preset."""
-        return self._area[area][CONF_PRESET][preset][CONF_FADE]
+        try:
+            return self._area[area][CONF_PRESET][preset][CONF_FADE]
+        except KeyError:
+            return self._default_fade
 
     def get_multi_name(self, area: int) -> str:
         """Return the name of a multi-device."""
@@ -430,15 +513,24 @@ class DynaliteDevices:
 
     def get_device_class(self, area: int) -> str:
         """Return the class for a blind."""
-        return self._area[area][CONF_DEVICE_CLASS]
+        try:
+            return self._area[area][CONF_DEVICE_CLASS]
+        except KeyError:
+            return DEFAULT_COVER_CLASS
 
     def get_cover_duration(self, area: int) -> float:
         """Return the class for a blind."""
-        return self._area[area][CONF_DURATION]
+        try:
+            return self._area[area][CONF_DURATION]
+        except KeyError:
+            return 60
 
     def get_cover_tilt_duration(self, area: int) -> float:
         """Return the class for a blind."""
-        return self._area[area][CONF_TILT_TIME]
+        try:
+            return self._area[area][CONF_TILT_TIME]
+        except KeyError:
+            return 0
 
     def get_master_area(self, area: int) -> str:
         """Get the master area when combining entities from different Dynet areas to the same area."""
